#!/usr/bin/env ruby

require 'fileutils'
require 'optparse'

options = {
  backup_directory: '/var/backups/logging-service'
}
parser = OptionParser.new do |params|
  params.banner = 'The script backups the old logs and archives them'

  params.on('-dDIRECTORY', '--directory=DIRECTORY',
      'The directory where the logs are stored') do |path|
    options[:log_directory] = File.expand_path(path)
  end

  params.on('-bDIRECTORY', '--backup=DIRECTORY', 
      'The directory to store the backups') do |path|
    options[:backup_directory] = File.expand_path(path)
  end
end
parser.parse!

unless options.key?(:log_directory)
  puts 'Please specify the log directory to store data in.'
  puts parser.help
  exit 1
end

unless Dir.exist?(options[:log_directory])
  puts 'The logging directory does not exist.'
  puts parser.help
  exit 1
end

begin
  FileUtils.mkdir_p(options[:backup_directory])
rescue
  puts 'Unable to create the backup directory!'
  puts 'Please specify the path to backup directory.'
  puts parser.help
  exit 1
end

FileUtils.cd(options[:log_directory])
log_files = Dir.entries(options[:log_directory])
log_files = log_files.reject { |file| file.start_with?('.') }
log_files.pop

if log_files.empty?
  puts 'No files to backup'
  exit
end

backup_file_name = File.join(options[:backup_directory],
  "#{Time.now.strftime('%F-%H-%M-%S')}.tgz")

puts "Backupping files #{log_files.join(', ')} into #{backup_file_name}"
`tar czf #{backup_file_name} #{log_files.join(' ')}`
puts 'Removing backuped log files'
FileUtils.rm(log_files)
