#!/usr/bin/env ruby

require 'optparse'

options = {
  pid_file: '/var/run/logging-service.pid',
  sleep_duration: 10
}
parser = OptionParser.new do |params|
  params.banner = 'Service does something really usefull and logs it!'

  params.on('-dDIRECTORY', '--directory=DIRECTORY', 'Directory to store data') do |path|
    options[:output_directory] = File.expand_path(path)
  end

  params.on('-pPID_FILE', '--pid-file=PID_FILE', 'Path to the PID file') do |path|
    options[:pid_file] = File.expand_path(path)
  end

  params.on('-sSLEEP_TIME', '--sleep-time=SLEEP_TIME', Integer,
     'How many seconds to sleep') do |duration|
    options[:sleep_duration] = duration
  end
end
parser.parse!

unless options.key?(:output_directory)
  puts 'Please provide the output directory'
  print parser.help
  exit 1
end

begin
  pid_file = File.open(options[:pid_file], 'w')
rescue
  puts "Unable to open PID file #{options[:pid_file]}"
  puts 'Please specify another location for the file'
  exit 1
end

child_id = fork
if child_id
  puts "Started service in the background with id: #{child_id}"
  pid_file.puts("#{child_id}")
  pid_file.close
  Process.detach(child_id)
  exit 0
end

continue = true
Signal.trap('TERM') do
  puts 'Shutting down'
  continue = false
end

log_file_index = 1
while continue
  file_name = sprintf('log-file-%05d', log_file_index)
  File.open(File.join(options[:output_directory], file_name), 'w') do |log_file|
    10.times do
      break unless continue
      process_count = `ps aux | wc -l`
      memory_info = `free -h`
      log_file.puts("System time: #{Time.now.strftime('%F-%H-%M-%S')}")
      log_file.puts("Process count: #{process_count}")
      log_file.puts('Memory information')
      log_file.puts(memory_info)
      sleep(options[:sleep_duration])
    end
  end
  log_file_index +=1
end
